==> blesta-5.10.2.zip: blesta/plugins/download_manager/language/zh_cn/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.add.field_public'] = '公开发布';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = '取消';
$lang['AdminMain.editcategory.submit_edit'] = '更新类别';
$lang['AdminMain.editcategory.field_description'] = '说明';
$lang['AdminMain.editcategory.field_name'] = '名称';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = '更新类别 [%1$s]';
$lang['AdminMain.editcategory.page_title'] = '下载管理器 > 更新类别';
$lang['AdminMain.addcategory.submit_cancel'] = '取消';
$lang['AdminMain.addcategory.submit_add'] = '创建类别';
$lang['AdminMain.addcategory.field_description'] = '说明';
$lang['AdminMain.addcategory.field_name'] = '名称';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = '将类别添加到类别 [%1$s] 中';
$lang['AdminMain.addcategory.boxtitle_root'] = '为 %1$s 添加类别';
$lang['AdminMain.addcategory.page_title'] = '下载管理器 > 添加类别';
$lang['AdminMain.editurl.submit_cancel'] = '取消';
$lang['AdminMain.editurl.submit_add'] = '编辑 URL';
$lang['AdminMain.editurl.field_category'] = '类别';
$lang['AdminMain.editurl.field_file'] = '文件';
$lang['AdminMain.editurl.field_url'] = 'URL 名称';
$lang['AdminMain.editurl.boxtitle_add'] = '编辑静态 URL';
$lang['AdminMain.editurl.page_title'] = '下载管理器 > 编辑静态 URL';
$lang['AdminMain.edit.submit_cancel'] = '取消';
$lang['AdminMain.edit.submit_edit'] = '更新下载';
$lang['AdminMain.edit.field_file_name'] = '文件路径';
$lang['AdminMain.edit.field_file'] = '文件';
$lang['AdminMain.edit.field_path'] = '指定文件路径';
$lang['AdminMain.edit.field_upload'] = '上传文件';
$lang['AdminMain.edit.text_availablepackages'] = '可用套餐';
$lang['AdminMain.edit.text_availableclientgroups'] = '可用客户群';
$lang['AdminMain.edit.text_packagegroups'] = '精选套餐';
$lang['AdminMain.edit.text_clientgroups'] = '部分客户群';
$lang['AdminMain.edit.field_available_to_packages'] = '适用于套餐';
$lang['AdminMain.edit.field_available_to_client_groups'] = '提供给客户群';
$lang['AdminMain.edit.field_name'] = '名称';
$lang['AdminMain.edit.field_logged_in'] = '必须登录';
$lang['AdminMain.edit.field_public'] = '公开发布';
$lang['AdminMain.edit.boxtitle_edit'] = '更新下载';
$lang['AdminMain.edit.page_title'] = '下载管理器 > 添加下载';
$lang['AdminMain.addurl.submit_cancel'] = '取消';
$lang['AdminMain.addurl.submit_add'] = '添加 URL';
$lang['AdminMain.addurl.field_category'] = '类别';
$lang['AdminMain.addurl.field_file'] = '文件';
$lang['AdminMain.addurl.field_url'] = 'URL 名称';
$lang['AdminMain.addurl.boxtitle_add'] = '添加静态 URL';
$lang['AdminMain.addurl.page_title'] = '下载管理器 > 添加静态 URL';
$lang['AdminMain.add.submit_cancel'] = '取消';
$lang['AdminMain.add.submit_add'] = '添加下载';
$lang['AdminMain.add.field_file_name'] = '文件路径';
$lang['AdminMain.add.field_file'] = '文件';
$lang['AdminMain.add.field_path'] = '指定文件路径';
$lang['AdminMain.add.field_upload'] = '上传文件';
$lang['AdminMain.add.text_availablepackages'] = '可用套餐';
$lang['AdminMain.add.text_availableclientgroups'] = '可用客户群';
$lang['AdminMain.add.text_packagegroups'] = '精选套餐';
$lang['AdminMain.add.text_clientgroups'] = '部分客户群';
$lang['AdminMain.add.field_available_to_packages'] = '适用于套餐';
$lang['AdminMain.add.field_available_to_client_groups'] = '提供给客户群';
$lang['AdminMain.add.field_name'] = '名称';
$lang['AdminMain.add.field_logged_in'] = '必须登录';
$lang['AdminMain.add.boxtitle_add'] = '将下载添加到类别 [%1$s] 中';
$lang['AdminMain.add.boxtitle_root'] = '将下载添加到 %1$s';
$lang['AdminMain.add.page_title'] = '下载管理器 > 添加下载';
$lang['AdminMain.urls.no_urls'] = '本部分没有静态 URL。';
$lang['AdminMain.urls.latest_file'] = '来自 <strong>%1$s</strong> 的最新文件';
$lang['AdminMain.urls.delete'] = '删除';
$lang['AdminMain.urls.edit'] = '编辑';
$lang['AdminMain.urls.heading_options'] = '选项';
$lang['AdminMain.urls.heading_link'] = '链接';
$lang['AdminMain.urls.heading_file'] = '文件';
$lang['AdminMain.urls.heading_url'] = '网址';
$lang['AdminMain.urls.tab_urls'] = '静态 URL';
$lang['AdminMain.urls.tab_files'] = '文件';
$lang['AdminMain.urls.add_url'] = '添加静态 URL';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = '下载管理器';
$lang['AdminMain.urls.page_title'] = '下载管理器 > 管理';
$lang['AdminMain.files.no_downloads'] = '本部分没有下载。';
$lang['AdminMain.files.delete'] = '删除';
$lang['AdminMain.files.edit'] = '编辑';
$lang['AdminMain.files.go_back'] = '升一级';
$lang['AdminMain.files.add_category'] = '在此添加类别';
$lang['AdminMain.files.add_download'] = '在此添加下载';
$lang['AdminMain.files.tab_urls'] = '静态 URL';
$lang['AdminMain.files.tab_files'] = '文件';
$lang['AdminMain.files.boxtitle_downloadmanager'] = '下载管理器';
$lang['AdminMain.files.page_title'] = '下载管理器 > 管理';
$lang['AdminMain.modal.delete_url'] = '您确定要删除这个静态 URL 吗？';
$lang['AdminMain.modal.delete_category'] = '您确定要删除此类别吗？该类别中的所有子类别和文件都将移至父类别。';
$lang['AdminMain.modal.delete_file'] = '您确定要删除此文件吗？';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = '主页目录';
$lang['AdminMain.!tooltip.category_type'] = 'URL 将指向上传到该类别的最后一个文件。';
$lang['AdminMain.!tooltip.path_to_file'] = '输入文件系统中文件的绝对路径。';
$lang['AdminMain.!success.url_updated'] = '静态 URL 已成功更新。';
$lang['AdminMain.!success.url_added'] = '静态 URL 已成功添加。';
$lang['AdminMain.!success.url_deleted'] = '静态 URL 已成功删除。';
$lang['AdminMain.!success.file_deleted'] = '文件已成功删除。';
$lang['AdminMain.!success.file_updated'] = '文件已成功更新。';
$lang['AdminMain.!success.file_added'] = '文件已成功添加。';
$lang['AdminMain.!success.category_deleted'] = '类别已成功删除。';
$lang['AdminMain.!success.category_updated'] = '类别已成功更新。';
$lang['AdminMain.!success.category_added'] = '类别已成功创建。';

==> blesta-5.11.4.zip: blesta/plugins/download_manager/language/zh_cn/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.add.field_public'] = '公开发布';
$lang['AdminMain.package_name'] = '%1$s (%2$s)';
$lang['AdminMain.editcategory.submit_cancel'] = '取消';
$lang['AdminMain.editcategory.submit_edit'] = '更新类别';
$lang['AdminMain.editcategory.field_description'] = '说明';
$lang['AdminMain.editcategory.field_name'] = '名称';
$lang['AdminMain.editcategory.boxtitle_editcategory'] = '更新类别 [%1$s]';
$lang['AdminMain.editcategory.page_title'] = '下载管理器 > 更新类别';
$lang['AdminMain.addcategory.submit_cancel'] = '取消';
$lang['AdminMain.addcategory.submit_add'] = '创建类别';
$lang['AdminMain.addcategory.field_description'] = '说明';
$lang['AdminMain.addcategory.field_name'] = '名称';
$lang['AdminMain.addcategory.boxtitle_addcategory'] = '将类别添加到类别 [%1$s] 中';
$lang['AdminMain.addcategory.boxtitle_root'] = '为 %1$s 添加类别';
$lang['AdminMain.addcategory.page_title'] = '下载管理器 > 添加类别';
$lang['AdminMain.editurl.submit_cancel'] = '取消';
$lang['AdminMain.editurl.submit_add'] = '编辑 URL';
$lang['AdminMain.editurl.field_category'] = '类别';
$lang['AdminMain.editurl.field_file'] = '文件';
$lang['AdminMain.editurl.field_url'] = 'URL 名称';
$lang['AdminMain.editurl.boxtitle_add'] = '编辑静态 URL';
$lang['AdminMain.editurl.page_title'] = '下载管理器 > 编辑静态 URL';
$lang['AdminMain.edit.submit_cancel'] = '取消';
$lang['AdminMain.edit.submit_edit'] = '更新下载';
$lang['AdminMain.edit.field_file_name'] = '文件路径';
$lang['AdminMain.edit.field_file'] = '文件';
$lang['AdminMain.edit.field_path'] = '指定文件路径';
$lang['AdminMain.edit.field_upload'] = '上传文件';
$lang['AdminMain.edit.text_availablepackages'] = '可用套餐';
$lang['AdminMain.edit.text_availableclientgroups'] = '可用客户群';
$lang['AdminMain.edit.text_packagegroups'] = '精选套餐';
$lang['AdminMain.edit.text_clientgroups'] = '部分客户群';
$lang['AdminMain.edit.field_available_to_packages'] = '适用于套餐';
$lang['AdminMain.edit.field_available_to_client_groups'] = '提供给客户群';
$lang['AdminMain.edit.field_name'] = '名称';
$lang['AdminMain.edit.field_logged_in'] = '必须登录';
$lang['AdminMain.edit.field_public'] = '公开发布';
$lang['AdminMain.edit.boxtitle_edit'] = '更新下载';
$lang['AdminMain.edit.page_title'] = '下载管理器 > 添加下载';
$lang['AdminMain.addurl.submit_cancel'] = '取消';
$lang['AdminMain.addurl.submit_add'] = '添加 URL';
$lang['AdminMain.addurl.field_category'] = '类别';
$lang['AdminMain.addurl.field_file'] = '文件';
$lang['AdminMain.addurl.field_url'] = 'URL 名称';
$lang['AdminMain.addurl.boxtitle_add'] = '添加静态 URL';
$lang['AdminMain.addurl.page_title'] = '下载管理器 > 添加静态 URL';
$lang['AdminMain.add.submit_cancel'] = '取消';
$lang['AdminMain.add.submit_add'] = '添加下载';
$lang['AdminMain.add.field_file_name'] = '文件路径';
$lang['AdminMain.add.field_file'] = '文件';
$lang['AdminMain.add.field_path'] = '指定文件路径';
$lang['AdminMain.add.field_upload'] = '上传文件';
$lang['AdminMain.add.text_availablepackages'] = '可用套餐';
$lang['AdminMain.add.text_availableclientgroups'] = '可用客户群';
$lang['AdminMain.add.text_packagegroups'] = '精选套餐';
$lang['AdminMain.add.text_clientgroups'] = '部分客户群';
$lang['AdminMain.add.field_available_to_packages'] = '适用于套餐';
$lang['AdminMain.add.field_available_to_client_groups'] = '提供给客户群';
$lang['AdminMain.add.field_name'] = '名称';
$lang['AdminMain.add.field_logged_in'] = '必须登录';
$lang['AdminMain.add.boxtitle_add'] = '将下载添加到类别 [%1$s] 中';
$lang['AdminMain.add.boxtitle_root'] = '将下载添加到 %1$s';
$lang['AdminMain.add.page_title'] = '下载管理器 > 添加下载';
$lang['AdminMain.urls.no_urls'] = '本部分没有静态 URL。';
$lang['AdminMain.urls.latest_file'] = '来自 <strong>%1$s</strong> 的最新文件';
$lang['AdminMain.urls.delete'] = '删除';
$lang['AdminMain.urls.edit'] = '编辑';
$lang['AdminMain.urls.heading_options'] = '选项';
$lang['AdminMain.urls.heading_link'] = '链接';
$lang['AdminMain.urls.heading_file'] = '文件';
$lang['AdminMain.urls.heading_url'] = '网址';
$lang['AdminMain.urls.tab_urls'] = '静态 URL';
$lang['AdminMain.urls.tab_files'] = '文件';
$lang['AdminMain.urls.add_url'] = '添加静态 URL';
$lang['AdminMain.urls.boxtitle_downloadmanager'] = '下载管理器';
$lang['AdminMain.urls.page_title'] = '下载管理器 > 管理';
$lang['AdminMain.files.no_downloads'] = '本部分没有下载。';
$lang['AdminMain.files.delete'] = '删除';
$lang['AdminMain.files.edit'] = '编辑';
$lang['AdminMain.files.go_back'] = '升一级';
$lang['AdminMain.files.add_category'] = '在此添加类别';
$lang['AdminMain.files.add_download'] = '在此添加下载';
$lang['AdminMain.files.tab_urls'] = '静态 URL';
$lang['AdminMain.files.tab_files'] = '文件';
$lang['AdminMain.files.boxtitle_downloadmanager'] = '下载管理器';
$lang['AdminMain.files.page_title'] = '下载管理器 > 管理';
$lang['AdminMain.modal.delete_url'] = '您确定要删除这个静态 URL 吗？';
$lang['AdminMain.modal.delete_category'] = '您确定要删除此类别吗？该类别中的所有子类别和文件都将移至父类别。';
$lang['AdminMain.modal.delete_file'] = '您确定要删除此文件吗？';
$lang['AdminMain.!text.closed_parenthesis'] = ')';
$lang['AdminMain.!text.forward_slash'] = '/';
$lang['AdminMain.!text.open_parenthesis'] = '(';
$lang['AdminMain.!text.root_directory'] = '主页目录';
$lang['AdminMain.!tooltip.category_type'] = 'URL 将指向上传到该类别的最后一个文件。';
$lang['AdminMain.!tooltip.path_to_file'] = '输入文件系统中文件的绝对路径。';
$lang['AdminMain.!success.url_updated'] = '静态 URL 已成功更新。';
$lang['AdminMain.!success.url_added'] = '静态 URL 已成功添加。';
$lang['AdminMain.!success.url_deleted'] = '静态 URL 已成功删除。';
$lang['AdminMain.!success.file_deleted'] = '文件已成功删除。';
$lang['AdminMain.!success.file_updated'] = '文件已成功更新。';
$lang['AdminMain.!success.file_added'] = '文件已成功添加。';
$lang['AdminMain.!success.category_deleted'] = '类别已成功删除。';
$lang['AdminMain.!success.category_updated'] = '类别已成功更新。';
$lang['AdminMain.!success.category_added'] = '类别已成功创建。';
$lang['AdminMain.edit.text_full_path'] = '注意：文件必须位于上传目录中的某个位置： <strong>%1$s</strong>.';
$lang['AdminMain.add.text_full_path'] = '注意：文件必须位于上传目录中的某个位置： <strong>%1$s</strong>.';
